@@ -42,11 +42,11 @@ use std::sync::atomic::{AtomicBool, Ordering};
 use std::sync::Arc;
 use std::time::{Duration, Instant};
 
-pub use crate::colors::AlphaOptim;
 pub use crate::deflate::Deflaters;
 pub use crate::error::PngError;
 pub use crate::filters::RowFilter;
 pub use crate::headers::Headers;
+pub use crate::interlace::Interlacing;
 pub use indexmap::{indexset, IndexMap, IndexSet};
 
 mod atomicmin;
@@ -158,9 +158,9 @@ pub struct Options {
     /// `Some(x)` will change the file to interlacing mode `x`.
     ///
     /// Default: `None`
-    pub interlace: Option<u8>,
-    /// Alpha filtering strategies to use
-    pub alphas: IndexSet<colors::AlphaOptim>,
+    pub interlace: Option<Interlacing>,
+    /// Whether to allow transparent pixels to be altered to improve compression.
+    pub optimize_alpha: bool,
     /// Whether to attempt bit depth reduction
     ///
     /// Default: `true`
@@ -295,7 +295,7 @@ impl Default for Options {
             preserve_attrs: false,
             filter: indexset! {RowFilter::None, RowFilter::Sub, RowFilter::Entropy, RowFilter::Bigrams},
             interlace: None,
-            alphas: IndexSet::new(),
+            optimize_alpha: false,
             bit_depth_reduction: true,
             color_type_reduction: true,
             palette_reduction: true,
@@ -470,20 +470,7 @@ fn optimize_png(
         "    {}x{} pixels, PNG format",
         png.raw.ihdr.width, png.raw.ihdr.height
     );
-    if let Some(ref palette) = png.raw.palette {
-        info!(
-            "    {} bits/pixel, {} colors in palette",
-            png.raw.ihdr.bit_depth,
-            palette.len()
-        );
-    } else {
-        info!(
-            "    {}x{} bits/pixel, {:?}",
-            png.raw.channels_per_pixel(),
-            png.raw.ihdr.bit_depth,
-            png.raw.ihdr.color_type
-        );
-    }
+    report_format("    ", &png.raw);
     info!("    IDAT size = {} bytes", idat_original_size);
     info!("    File size = {} bytes", file_original_size);
 
@@ -491,21 +478,47 @@ fn optimize_png(
     perform_strip(png, opts);
     let stripped_png = png.clone();
 
+    // Interlacing is not part of the evaluator trials but must be done first to evaluate the rest correctly
+    let mut reduction_occurred = false;
+    if let Some(interlacing) = opts.interlace {
+        if let Some(reduced) = png.raw.change_interlacing(interlacing) {
+            png.raw = Arc::new(reduced);
+            reduction_occurred = true;
+        }
+    }
+
+    // If alpha optimization is enabled, perform a black alpha reduction before evaluating reductions
+    // This can allow reductions from alpha to indexed which may not have been possible otherwise
+    if opts.optimize_alpha {
+        if let Some(reduced) = cleaned_alpha_channel(&png.raw) {
+            png.raw = Arc::new(reduced);
+        }
+    }
+
     // Must use normal (lazy) compression, as faster ones (greedy) are not representative
-    // Alpha reductions can benefit from higher compression but otherwise it's not beneficial
     let eval_compression = 5;
     // None and Bigrams work well together, especially for alpha reductions
     let eval_filters = indexset! {RowFilter::None, RowFilter::Bigrams};
     // This will collect all versions of images and pick one that compresses best
-    let eval = Evaluator::new(deadline.clone(), eval_filters.clone(), eval_compression);
+    let eval = Evaluator::new(
+        deadline.clone(),
+        eval_filters.clone(),
+        eval_compression,
+        false,
+    );
     perform_reductions(png.raw.clone(), opts, &deadline, &eval);
-    let (reduction_occurred, mut eval_filter) = if let Some(result) = eval.get_best_candidate() {
+    let mut eval_filter = if let Some(result) = eval.get_best_candidate() {
         *png = result.image;
-        (result.is_reduction, Some(result.filter))
+        reduction_occurred = true;
+        Some(result.filter)
     } else {
-        (false, None)
+        None
     };
 
+    if reduction_occurred {
+        report_format("Reducing image to ", &png.raw);
+    }
+
     if opts.idat_recoding || reduction_occurred {
         let mut filters = opts.filter.clone();
         let fast_eval = opts.fast_evaluation && (filters.len() > 1 || eval_filter.is_some());
@@ -519,7 +532,7 @@ fn optimize_png(
 
             if !filters.is_empty() {
                 debug!("Evaluating: {} filters", filters.len());
-                let eval = Evaluator::new(deadline, filters, eval_compression);
+                let eval = Evaluator::new(deadline, filters, eval_compression, opts.optimize_alpha);
                 if eval_filter.is_some() {
                     eval.set_best_size(png.idat_data.len());
                 }
@@ -537,7 +550,7 @@ fn optimize_png(
                     _ => 0,
                 },
             };
-            if trial.compression <= eval_compression {
+            if trial.compression > 0 && trial.compression <= eval_compression {
                 // No further compression required
                 if png.idat_data.len() < idat_original_size || opts.force {
                     Some((trial, png.idat_data.clone()))
@@ -585,7 +598,7 @@ fn optimize_png(
                 if deadline.passed() {
                     return None;
                 }
-                let filtered = &png.raw.filter_image(trial.filter);
+                let filtered = &png.raw.filter_image(trial.filter, opts.optimize_alpha);
                 perform_trial(filtered, opts, trial, &best_size)
             });
             best.reduce_with(|i, j| {
@@ -606,7 +619,7 @@ fn optimize_png(
                 opts.filter,
                 png.idat_data.len()
             );
-        } else if eval_filter.is_some() {
+        } else {
             *png = stripped_png;
         }
     } else if png.idat_data.len() >= idat_original_size {
@@ -644,28 +657,9 @@ fn optimize_png(
         );
     }
 
-    let (old_png, new_png) = rayon::join(
-        || load_png_image_from_memory(original_data),
-        || load_png_image_from_memory(&output),
-    );
+    debug_assert!(validate_output(&output, original_data));
 
-    if let Ok(new_png) = new_png {
-        if let Ok(old_png) = old_png {
-            if images_equal(&old_png, &new_png) {
-                return Ok(output);
-            }
-        } else {
-            // The original image might be invalid if, for example, there is a CRC error,
-            // and we set fix_errors to true. In that case, all we can do is check that the
-            // new image is decodable.
-            return Ok(output);
-        }
-    }
-
-    error!(
-        "The resulting image is corrupted and will not be outputted.\nThis is a bug! Please report it at https://github.com/shssoichiro/oxipng/issues"
-    );
-    Err(PngError::new("The resulting image is corrupted"))
+    Ok(output)
 }
 
 fn perform_reductions(
@@ -675,27 +669,13 @@ fn perform_reductions(
     eval: &Evaluator,
 ) {
     // The eval baseline will be set from the original png only if we attempt any reductions
-    let mut baseline = Some(png.clone());
+    let baseline = png.clone();
     let mut reduction_occurred = false;
 
-    // must be done first to evaluate rest with the correct interlacing
-    if let Some(interlacing) = opts.interlace {
-        if let Some(reduced) = png.change_interlacing(interlacing) {
-            png = Arc::new(reduced);
-            eval.try_image(png.clone());
-            // If we're interlacing, we have to accept a possible file size increase
-            baseline = None;
-        }
-        if deadline.passed() {
-            return;
-        }
-    }
-
     if opts.palette_reduction {
-        if let Some(reduced) = reduced_palette(&png) {
+        if let Some(reduced) = reduced_palette(&png, opts.optimize_alpha) {
             png = Arc::new(reduced);
             eval.try_image(png.clone());
-            report_reduction(&png);
             reduction_occurred = true;
         }
         if deadline.passed() {
@@ -717,7 +697,6 @@ fn perform_reductions(
                     eval.try_image(Arc::new(reduced));
                 }
             }
-            report_reduction(&png);
             reduction_occurred = true;
         }
         if deadline.passed() {
@@ -726,17 +705,11 @@ fn perform_reductions(
     }
 
     if opts.color_type_reduction {
-        // Perform a black alpha reduction before color type reductions
-        // This can allow reductions from alpha to indexed which may not have been possible otherwise
-        if !opts.alphas.is_empty() {
-            if let Some(reduced) = filtered_alpha_channel(&png, AlphaOptim::Black) {
-                png = Arc::new(reduced);
-            }
-        }
-        if let Some(reduced) = reduce_color_type(&png, opts.grayscale_reduction) {
+        if let Some(reduced) =
+            reduce_color_type(&png, opts.grayscale_reduction, opts.optimize_alpha)
+        {
             png = Arc::new(reduced);
             eval.try_image(png.clone());
-            report_reduction(&png);
             reduction_occurred = true;
         }
         if deadline.passed() {
@@ -744,14 +717,8 @@ fn perform_reductions(
         }
     }
 
-    if try_alpha_reductions(png, &opts.alphas, eval) {
-        reduction_occurred = true;
-    }
-
-    if let Some(baseline) = baseline {
-        if reduction_occurred {
-            eval.set_baseline(baseline);
-        }
+    if reduction_occurred {
+        eval.set_baseline(baseline);
     }
 }
 
@@ -843,20 +810,24 @@ impl Deadline {
     }
 }
 
-/// Display the status of the image data after a reduction has taken place
-fn report_reduction(png: &PngImage) {
+/// Display the format of the image data
+fn report_format(prefix: &str, png: &PngImage) {
     if let Some(ref palette) = png.palette {
         info!(
-            "Reducing image to {} bits/pixel, {} colors in palette",
+            "{}{} bits/pixel, {} colors in palette ({})",
+            prefix,
             png.ihdr.bit_depth,
-            palette.len()
+            palette.len(),
+            png.ihdr.interlaced
         );
     } else {
         info!(
-            "Reducing image to {}x{} bits/pixel, {}",
+            "{}{}x{} bits/pixel, {} ({})",
+            prefix,
             png.channels_per_pixel(),
             png.ihdr.bit_depth,
-            png.ihdr.color_type
+            png.ihdr.color_type,
+            png.ihdr.interlaced
         );
     }
 }
@@ -1071,6 +1042,29 @@ fn copy_times(input_path_meta: &Metadata, out_path: &Path) -> PngResult<()> {
     })
 }
 
+/// Validate that the output png data still matches the original image
+fn validate_output(output: &[u8], original_data: &[u8]) -> bool {
+    let (old_png, new_png) = rayon::join(
+        || load_png_image_from_memory(original_data),
+        || load_png_image_from_memory(output),
+    );
+
+    match (new_png, old_png) {
+        (Err(new_err), _) => {
+            error!("Failed to read output image for validation: {}", new_err);
+            false
+        }
+        (_, Err(old_err)) => {
+            // The original image might be invalid if, for example, there is a CRC error,
+            // and we set fix_errors to true. In that case, all we can do is check that the
+            // new image is decodable.
+            warn!("Failed to read input image for validation: {}", old_err);
+            true
+        }
+        (Ok(new_png), Ok(old_png)) => images_equal(&old_png, &new_png),
+    }
+}
+
 /// Loads a PNG image from memory to a [DynamicImage]
 fn load_png_image_from_memory(png_data: &[u8]) -> Result<DynamicImage, image::ImageError> {
     let mut reader = image::io::Reader::new(Cursor::new(png_data));
