@@ -16,7 +16,6 @@
 use clap::{AppSettings, Arg, ArgMatches, Command};
 use indexmap::IndexSet;
 use log::{error, warn};
-use oxipng::AlphaOptim;
 use oxipng::Deflaters;
 use oxipng::Headers;
 use oxipng::Options;
@@ -394,13 +393,13 @@ fn parse_opts_into_struct(
     };
 
     if let Some(x) = matches.value_of("interlace") {
-        opts.interlace = x.parse::<u8>().ok();
+        opts.interlace = x.parse::<u8>().unwrap().try_into().ok();
     }
 
     if let Some(x) = matches.value_of("filters") {
         opts.filter.clear();
         for f in parse_numeric_range_opts(x, 0, RowFilter::LAST).unwrap() {
-            opts.filter.insert(RowFilter::try_from(f).unwrap());
+            opts.filter.insert(f.try_into().unwrap());
         }
     }
 
@@ -438,10 +437,7 @@ fn parse_opts_into_struct(
     };
 
     if matches.is_present("alpha") {
-        opts.alphas.insert(AlphaOptim::Black);
-        opts.alphas.insert(AlphaOptim::White);
-        opts.alphas.insert(AlphaOptim::Up);
-        opts.alphas.insert(AlphaOptim::Left);
+        opts.optimize_alpha = true;
     }
 
     if matches.is_present("fast") {
