@@ -3,7 +3,7 @@ use crate::deflate;
 use crate::error::PngError;
 use crate::filters::*;
 use crate::headers::*;
-use crate::interlace::{deinterlace_image, interlace_image};
+use crate::interlace::{deinterlace_image, interlace_image, Interlacing};
 use bitvec::bitarr;
 use indexmap::IndexMap;
 use libdeflater::{CompressionLvl, Compressor};
@@ -18,7 +18,7 @@ use std::sync::Arc;
 
 pub(crate) mod scan_lines;
 
-use self::scan_lines::{ScanLines, ScanLinesMut};
+use self::scan_lines::ScanLines;
 
 /// Compression level to use for the Brute filter strategy
 const BRUTE_LEVEL: i32 = 1; // 1 is fastest, 2-4 are not useful, 5 is slower but more effective
@@ -29,7 +29,7 @@ const BRUTE_LINES: usize = 4; // Values over 8 are generally not useful
 pub struct PngImage {
     /// The headers stored in the IHDR chunk
     pub ihdr: IhdrData,
-    /// The uncompressed, optionally filtered data from the IDAT chunk
+    /// The uncompressed, unfiltered data from the IDAT chunk
     pub data: Vec<u8>,
     /// The palette containing colors used in an Indexed image
     /// Contains 3 bytes per color (R+G+B), up to 768
@@ -187,7 +187,7 @@ impl PngData {
             .ok();
         ihdr_data.write_all(&[0]).ok(); // Compression -- deflate
         ihdr_data.write_all(&[0]).ok(); // Filter method -- 5-way adaptive filtering
-        ihdr_data.write_all(&[self.raw.ihdr.interlaced]).ok();
+        ihdr_data.write_all(&[self.raw.ihdr.interlaced as u8]).ok();
         write_png_block(b"IHDR", &ihdr_data, &mut output);
         // Ancillary headers
         for (key, header) in self
@@ -258,12 +258,12 @@ impl PngImage {
     /// Assumes that the data has already been de-filtered
     #[inline]
     #[must_use]
-    pub fn change_interlacing(&self, interlace: u8) -> Option<PngImage> {
+    pub fn change_interlacing(&self, interlace: Interlacing) -> Option<PngImage> {
         if interlace == self.ihdr.interlaced {
             return None;
         }
 
-        Some(if interlace == 1 {
+        Some(if interlace == Interlacing::Adam7 {
             // Convert progressive to interlaced data
             interlace_image(self)
         } else {
@@ -280,14 +280,8 @@ impl PngImage {
 
     /// Return an iterator over the scanlines of the image
     #[inline]
-    pub fn scan_lines(&self) -> ScanLines<'_> {
-        ScanLines::new(self)
-    }
-
-    /// Return an iterator over the scanlines of the image
-    #[inline]
-    pub fn scan_lines_mut(&mut self) -> ScanLinesMut<'_> {
-        ScanLinesMut::new(self)
+    pub fn scan_lines(&self, has_filter: bool) -> ScanLines<'_> {
+        ScanLines::new(self, has_filter)
     }
 
     /// Reverse all filters applied on the image, returning an unfiltered IDAT bytestream
@@ -297,7 +291,7 @@ impl PngImage {
         let mut last_line: Vec<u8> = Vec::new();
         let mut last_pass = None;
         let mut unfiltered_buf = Vec::new();
-        for line in self.scan_lines() {
+        for line in self.scan_lines(true) {
             if last_pass != line.pass {
                 last_line.clear();
                 last_pass = line.pass;
@@ -305,7 +299,6 @@ impl PngImage {
             last_line.resize(line.data.len(), 0);
             let filter = RowFilter::try_from(line.filter).map_err(|_| PngError::InvalidData)?;
             filter.unfilter_line(bpp, line.data, &last_line, &mut unfiltered_buf)?;
-            unfiltered.push(0);
             unfiltered.extend_from_slice(&unfiltered_buf);
             std::mem::swap(&mut last_line, &mut unfiltered_buf);
             unfiltered_buf.clear();
@@ -314,31 +307,43 @@ impl PngImage {
     }
 
     /// Apply the specified filter type to all rows in the image
-    pub fn filter_image(&self, filter: RowFilter) -> Vec<u8> {
+    pub fn filter_image(&self, filter: RowFilter, optimize_alpha: bool) -> Vec<u8> {
         let mut filtered = Vec::with_capacity(self.data.len());
         let bpp = ((self.ihdr.bit_depth.as_u8() * self.channels_per_pixel() + 7) / 8) as usize;
-        let mut last_line: &[u8] = &[];
-        let mut last_pass: Option<u8> = None;
-        let mut f_buf = Vec::new();
-        for line in self.scan_lines() {
-            if last_pass != line.pass {
-                last_line = &[];
+        // If alpha optimization is enabled, determine how many bytes of alpha there are per pixel
+        let alpha_bytes = match self.ihdr.color_type {
+            ColorType::RGBA | ColorType::GrayscaleAlpha if optimize_alpha => {
+                (self.ihdr.bit_depth.as_u8() / 8) as usize
             }
+            _ => 0,
+        };
+
+        let mut prev_line = Vec::new();
+        let mut prev_pass: Option<u8> = None;
+        let mut f_buf = Vec::new();
+        for line in self.scan_lines(false) {
+            if prev_pass != line.pass || line.data.len() != prev_line.len() {
+                prev_line = vec![0; line.data.len()];
+            }
+            // Alpha optimisation may alter the line data, so we need a mutable copy of it
+            let mut line_data = line.data.to_vec();
 
             if filter <= RowFilter::Paeth {
                 // Standard filters
-                let filter = if last_pass == line.pass || filter <= RowFilter::Sub {
+                let filter = if prev_pass == line.pass || filter <= RowFilter::Sub {
                     filter
                 } else {
                     RowFilter::None
                 };
-                filter.filter_line(bpp, line.data, last_line, &mut f_buf);
+                filter.filter_line(bpp, &mut line_data, &prev_line, &mut f_buf, alpha_bytes);
                 filtered.extend_from_slice(&f_buf);
+                prev_line = line_data;
             } else {
                 // Heuristic filter selection strategies
                 let mut best_line = Vec::new();
+                let mut best_line_raw = Vec::new();
                 // Avoid vertical filtering on first line of each interlacing pass
-                let try_filters = if last_pass == line.pass {
+                let try_filters = if prev_pass == line.pass {
                     RowFilter::STANDARD.iter()
                 } else {
                     RowFilter::SINGLE_LINE.iter()
@@ -348,8 +353,8 @@ impl PngImage {
                         // MSAD algorithm mentioned in libpng reference docs
                         // http://www.libpng.org/pub/png/book/chapter09.html
                         let mut best_size = usize::MAX;
-                        for try_filter in try_filters {
-                            try_filter.filter_line(bpp, line.data, last_line, &mut f_buf);
+                        for f in try_filters {
+                            f.filter_line(bpp, &mut line_data, &prev_line, &mut f_buf, alpha_bytes);
                             let size = f_buf.iter().fold(0, |acc, &x| {
                                 let signed = x as i8;
                                 acc + signed.unsigned_abs() as usize
@@ -357,6 +362,7 @@ impl PngImage {
                             if size < best_size {
                                 best_size = size;
                                 std::mem::swap(&mut best_line, &mut f_buf);
+                                best_line_raw = line_data.clone();
                             }
                         }
                     }
@@ -364,8 +370,8 @@ impl PngImage {
                         // Shannon entropy algorithm, from LodePNG
                         // https://github.com/lvandeve/lodepng
                         let mut best_size = i32::MIN;
-                        for try_filter in try_filters {
-                            try_filter.filter_line(bpp, line.data, last_line, &mut f_buf);
+                        for f in try_filters {
+                            f.filter_line(bpp, &mut line_data, &prev_line, &mut f_buf, alpha_bytes);
                             let mut counts = vec![0; 0x100];
                             for &i in f_buf.iter() {
                                 counts[i as usize] += 1;
@@ -379,6 +385,7 @@ impl PngImage {
                             if size > best_size {
                                 best_size = size;
                                 std::mem::swap(&mut best_line, &mut f_buf);
+                                best_line_raw = line_data.clone();
                             }
                         }
                     }
@@ -386,8 +393,8 @@ impl PngImage {
                         // Count distinct bigrams, from pngwolf
                         // https://bjoern.hoehrmann.de/pngwolf/
                         let mut best_size = usize::MAX;
-                        for try_filter in try_filters {
-                            try_filter.filter_line(bpp, line.data, last_line, &mut f_buf);
+                        for f in try_filters {
+                            f.filter_line(bpp, &mut line_data, &prev_line, &mut f_buf, alpha_bytes);
                             let mut set = bitarr![0; 0x10000];
                             for pair in f_buf.windows(2) {
                                 let bigram = (pair[0] as usize) << 8 | pair[1] as usize;
@@ -397,6 +404,7 @@ impl PngImage {
                             if size < best_size {
                                 best_size = size;
                                 std::mem::swap(&mut best_line, &mut f_buf);
+                                best_line_raw = line_data.clone();
                             }
                         }
                     }
@@ -405,8 +413,8 @@ impl PngImage {
                         let mut best_size = i32::MIN;
                         // FxHasher is the fastest rust hasher currently available for this purpose
                         let mut counts = FxHashMap::<u16, u32>::default();
-                        for try_filter in try_filters {
-                            try_filter.filter_line(bpp, line.data, last_line, &mut f_buf);
+                        for f in try_filters {
+                            f.filter_line(bpp, &mut line_data, &prev_line, &mut f_buf, alpha_bytes);
                             counts.clear();
                             for pair in f_buf.windows(2) {
                                 let bigram = (pair[0] as u16) << 8 | pair[1] as u16;
@@ -416,6 +424,7 @@ impl PngImage {
                             if size > best_size {
                                 best_size = size;
                                 std::mem::swap(&mut best_line, &mut f_buf);
+                                best_line_raw = line_data.clone();
                             }
                         }
                     }
@@ -431,8 +440,8 @@ impl PngImage {
                         let capacity = compressor.zlib_compress_bound(limit);
                         let mut dest = vec![0; capacity];
 
-                        for try_filter in try_filters {
-                            try_filter.filter_line(bpp, line.data, last_line, &mut f_buf);
+                        for f in try_filters {
+                            f.filter_line(bpp, &mut line_data, &prev_line, &mut f_buf, alpha_bytes);
                             filtered[line_start..].copy_from_slice(&f_buf);
                             let size = compressor
                                 .zlib_compress(&filtered[filtered.len() - limit..], &mut dest)
@@ -440,6 +449,7 @@ impl PngImage {
                             if size < best_size {
                                 best_size = size;
                                 std::mem::swap(&mut best_line, &mut f_buf);
+                                best_line_raw = line_data.clone();
                             }
                         }
                         filtered.resize(line_start, 0);
@@ -447,10 +457,10 @@ impl PngImage {
                     _ => unreachable!(),
                 }
                 filtered.extend_from_slice(&best_line);
+                prev_line = best_line_raw;
             }
 
-            last_line = line.data;
-            last_pass = line.pass;
+            prev_pass = line.pass;
         }
         filtered
     }
