@@ -1,5 +1,5 @@
 use indexmap::IndexSet;
-use oxipng::{internal_tests::*, RowFilter};
+use oxipng::{internal_tests::*, Interlacing, RowFilter};
 use oxipng::{InFile, OutFile};
 use std::fs::remove_file;
 use std::path::Path;
@@ -92,11 +92,11 @@ fn issue_29() {
 fn issue_42() {
     let input = PathBuf::from("tests/files/issue_42.png");
     let (output, mut opts) = get_opts(&input);
-    opts.interlace = Some(1);
+    opts.interlace = Some(Interlacing::Adam7);
 
     let png = PngData::new(&input, opts.fix_errors).unwrap();
 
-    assert_eq!(png.raw.ihdr.interlaced, 0);
+    assert_eq!(png.raw.ihdr.interlaced, Interlacing::None);
     assert_eq!(png.raw.ihdr.color_type, ColorType::GrayscaleAlpha);
     assert_eq!(png.raw.ihdr.bit_depth, BitDepth::Eight);
 
@@ -115,7 +115,7 @@ fn issue_42() {
         }
     };
 
-    assert_eq!(png.raw.ihdr.interlaced, 1);
+    assert_eq!(png.raw.ihdr.interlaced, Interlacing::Adam7);
     assert_eq!(png.raw.ihdr.color_type, ColorType::GrayscaleAlpha);
     assert_eq!(png.raw.ihdr.bit_depth, BitDepth::Eight);
 
@@ -308,103 +308,11 @@ fn issue_92_filter_5() {
 }
 
 #[test]
-fn issue_113_white() {
+fn issue_113() {
     let input = "tests/files/issue-113.png";
-    let (_, mut opts) = get_opts(Path::new(input));
-    opts.interlace = Some(1);
-    opts.alphas = IndexSet::new();
-    opts.alphas.insert(AlphaOptim::Black);
-    let output = OutFile::Path(Some(Path::new(input).with_extension("-white-out.png")));
-    test_it_converts(
-        input,
-        Some((output, opts)),
-        ColorType::RGBA,
-        BitDepth::Eight,
-        ColorType::GrayscaleAlpha,
-        BitDepth::Eight,
-    );
-}
-
-#[test]
-fn issue_113_black() {
-    let input = "tests/files/issue-113.png";
-    let (_, mut opts) = get_opts(Path::new(input));
-    opts.interlace = Some(1);
-    opts.alphas = IndexSet::new();
-    opts.alphas.insert(AlphaOptim::Black);
-    let output = OutFile::Path(Some(Path::new(input).with_extension("-black-out.png")));
-    test_it_converts(
-        input,
-        Some((output, opts)),
-        ColorType::RGBA,
-        BitDepth::Eight,
-        ColorType::GrayscaleAlpha,
-        BitDepth::Eight,
-    );
-}
-
-#[test]
-fn issue_113_right() {
-    let input = "tests/files/issue-113.png";
-    let (_, mut opts) = get_opts(Path::new(input));
-    opts.interlace = Some(1);
-    opts.alphas = IndexSet::new();
-    opts.alphas.insert(AlphaOptim::Right);
-    let output = OutFile::Path(Some(Path::new(input).with_extension("-right-out.png")));
-    test_it_converts(
-        input,
-        Some((output, opts)),
-        ColorType::RGBA,
-        BitDepth::Eight,
-        ColorType::GrayscaleAlpha,
-        BitDepth::Eight,
-    );
-}
-
-#[test]
-fn issue_113_left() {
-    let input = "tests/files/issue-113.png";
-    let (_, mut opts) = get_opts(Path::new(input));
-    opts.interlace = Some(1);
-    opts.alphas = IndexSet::new();
-    opts.alphas.insert(AlphaOptim::Left);
-    let output = OutFile::Path(Some(Path::new(input).with_extension("-left-out.png")));
-    test_it_converts(
-        input,
-        Some((output, opts)),
-        ColorType::RGBA,
-        BitDepth::Eight,
-        ColorType::GrayscaleAlpha,
-        BitDepth::Eight,
-    );
-}
-
-#[test]
-fn issue_113_up() {
-    let input = "tests/files/issue-113.png";
-    let (_, mut opts) = get_opts(Path::new(input));
-    opts.interlace = Some(1);
-    opts.alphas = IndexSet::new();
-    opts.alphas.insert(AlphaOptim::Up);
-    let output = OutFile::Path(Some(Path::new(input).with_extension("-up-out.png")));
-    test_it_converts(
-        input,
-        Some((output, opts)),
-        ColorType::RGBA,
-        BitDepth::Eight,
-        ColorType::GrayscaleAlpha,
-        BitDepth::Eight,
-    );
-}
-
-#[test]
-fn issue_113_down() {
-    let input = "tests/files/issue-113.png";
-    let (_, mut opts) = get_opts(Path::new(input));
-    opts.interlace = Some(1);
-    opts.alphas = IndexSet::new();
-    opts.alphas.insert(AlphaOptim::Down);
-    let output = OutFile::Path(Some(Path::new(input).with_extension("-down-out.png")));
+    let (output, mut opts) = get_opts(Path::new(input));
+    opts.interlace = Some(Interlacing::Adam7);
+    opts.optimize_alpha = true;
     test_it_converts(
         input,
         Some((output, opts)),
@@ -429,97 +337,10 @@ fn issue_129() {
 }
 
 #[test]
-fn issue_133_black() {
+fn issue_133() {
     let input = "tests/files/issue-133.png";
-    let (_, mut opts) = get_opts(Path::new(input));
-    opts.alphas = IndexSet::new();
-    opts.alphas.insert(AlphaOptim::Black);
-    let output = OutFile::Path(Some(Path::new(input).with_extension("-black-out.png")));
-    test_it_converts(
-        input,
-        Some((output, opts)),
-        ColorType::RGBA,
-        BitDepth::Eight,
-        ColorType::RGBA,
-        BitDepth::Eight,
-    );
-}
-
-#[test]
-fn issue_133_white() {
-    let input = "tests/files/issue-133.png";
-    let (_, mut opts) = get_opts(Path::new(input));
-    opts.alphas = IndexSet::new();
-    opts.alphas.insert(AlphaOptim::White);
-    let output = OutFile::Path(Some(Path::new(input).with_extension("-white-out.png")));
-    test_it_converts(
-        input,
-        Some((output, opts)),
-        ColorType::RGBA,
-        BitDepth::Eight,
-        ColorType::RGBA,
-        BitDepth::Eight,
-    );
-}
-
-#[test]
-fn issue_133_up() {
-    let input = "tests/files/issue-133.png";
-    let (_, mut opts) = get_opts(Path::new(input));
-    opts.alphas = IndexSet::new();
-    opts.alphas.insert(AlphaOptim::Up);
-    let output = OutFile::Path(Some(Path::new(input).with_extension("-up-out.png")));
-    test_it_converts(
-        input,
-        Some((output, opts)),
-        ColorType::RGBA,
-        BitDepth::Eight,
-        ColorType::RGBA,
-        BitDepth::Eight,
-    );
-}
-
-#[test]
-fn issue_133_down() {
-    let input = "tests/files/issue-133.png";
-    let (_, mut opts) = get_opts(Path::new(input));
-    opts.alphas = IndexSet::new();
-    opts.alphas.insert(AlphaOptim::Down);
-    let output = OutFile::Path(Some(Path::new(input).with_extension("-down-out.png")));
-    test_it_converts(
-        input,
-        Some((output, opts)),
-        ColorType::RGBA,
-        BitDepth::Eight,
-        ColorType::RGBA,
-        BitDepth::Eight,
-    );
-}
-
-#[test]
-fn issue_133_right() {
-    let input = "tests/files/issue-133.png";
-    let (_, mut opts) = get_opts(Path::new(input));
-    opts.alphas = IndexSet::new();
-    opts.alphas.insert(AlphaOptim::Right);
-    let output = OutFile::Path(Some(Path::new(input).with_extension("-right-out.png")));
-    test_it_converts(
-        input,
-        Some((output, opts)),
-        ColorType::RGBA,
-        BitDepth::Eight,
-        ColorType::RGBA,
-        BitDepth::Eight,
-    );
-}
-
-#[test]
-fn issue_133_left() {
-    let input = "tests/files/issue-133.png";
-    let (_, mut opts) = get_opts(Path::new(input));
-    opts.alphas = IndexSet::new();
-    opts.alphas.insert(AlphaOptim::Left);
-    let output = OutFile::Path(Some(Path::new(input).with_extension("-left-out.png")));
+    let (output, mut opts) = get_opts(Path::new(input));
+    opts.optimize_alpha = true;
     test_it_converts(
         input,
         Some((output, opts)),
@@ -619,7 +440,7 @@ fn issue_175() {
 fn issue_182() {
     let input = "tests/files/issue-182.png";
     let (output, mut opts) = get_opts(Path::new(input));
-    opts.interlace = Some(0);
+    opts.interlace = Some(Interlacing::Adam7);
 
     test_it_converts(
         input,
@@ -642,3 +463,27 @@ fn issue_195() {
         BitDepth::Eight,
     );
 }
+
+#[test]
+fn issue_426_01() {
+    test_it_converts(
+        "tests/files/issue-426-01.png",
+        None,
+        ColorType::Grayscale,
+        BitDepth::Eight,
+        ColorType::Grayscale,
+        BitDepth::One,
+    );
+}
+
+#[test]
+fn issue_426_02() {
+    test_it_converts(
+        "tests/files/issue-426-02.png",
+        None,
+        ColorType::Grayscale,
+        BitDepth::Eight,
+        ColorType::Grayscale,
+        BitDepth::One,
+    );
+}
